@@ -925,6 +925,7 @@ def test_stack(sky_model):
 
     assert_allclose(npred_b.data.sum(), 1459.985035, 1e-5)
     assert_allclose(stacked.npred_background().data.sum(), 1360.00, 1e-5)
+    assert_allclose(stacked.background.data.sum(), 1360, 1e-5)
     assert_allclose(stacked.counts.data.sum(), 9000, 1e-5)
     assert_allclose(stacked.mask_safe.data.sum(), 4600)
     assert_allclose(stacked.mask_fit.data.sum(), 4600)
@@ -932,6 +933,14 @@ def test_stack(sky_model):
 
     assert_allclose(stacked.meta_table["OBS_ID"][0], [0, 1])
 
+    # stacking when no safe masks are defined
+    dataset1 = MapDataset(counts=cnt1, background=bkg1)
+    stacked = MapDataset.from_geoms(**dataset1.geoms)
+    for i in range(3):
+        stacked.stack(dataset1)
+    assert_allclose(stacked.background.data.sum(), 2880.0, 1e-5)
+    assert_allclose(stacked.counts.data.sum(), 14400.0, 1e-5)
+
 
 @requires_data()
 def test_npred(sky_model, geom, geom_etrue):
