@@ -97,6 +97,8 @@ class Background3D(BackgroundIRF):
         Data array.
     unit : str or `~astropy.units.Unit`
         Data unit usually ``s^-1 MeV^-1 sr^-1``
+    fov_alignment: `~gammapy.irf.FoVAlignment`
+        The orientation of the field of view coordinate system.
     meta : dict
         Meta data
 
@@ -338,7 +340,7 @@ class Background2D(BackgroundIRF):
                 ax.plot(offset_axis.center, bkg, label=label, **kwargs)
 
         offset_axis.format_plot_xaxis(ax=ax)
-        ax.set_ylabel(f"Background rate ({ax.yaxis.units})")
+        ax.set_ylabel(f"Background rate [{ax.yaxis.units}]")
         ax.set_yscale("log")
         ax.legend(loc="upper right")
         return ax
@@ -377,7 +379,7 @@ class Background2D(BackgroundIRF):
 
         energy_axis.format_plot_xaxis(ax=ax)
         ax.set_yscale("log")
-        ax.set_ylabel(f"Background rate ({ax.yaxis.units})")
+        ax.set_ylabel(f"Background rate [{ax.yaxis.units}]")
         ax.legend(loc="best")
         return ax
 
@@ -408,7 +410,7 @@ class Background2D(BackgroundIRF):
 
         energy_axis.format_plot_xaxis(ax=ax)
         ax.set_yscale("log")
-        ax.set_ylabel(f"Background rate ({ax.yaxis.units})")
+        ax.set_ylabel(f"Background rate [{ax.yaxis.units}]")
         ax.legend(loc="best")
         return ax
 
