@@ -1,6 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import copy
 import inspect
+import logging
 from collections.abc import Sequence
 import numpy as np
 import scipy
@@ -16,6 +17,8 @@ from .utils import INVALID_INDEX, edges_from_lo_hi
 
 __all__ = ["MapAxes", "MapAxis", "TimeMapAxis", "LabelMapAxis"]
 
+log = logging.getLogger(__name__)
+
 
 def flat_if_equal(array):
     if array.ndim == 2 and np.all(array == array[0]):
@@ -884,7 +887,8 @@ class MapAxis:
 
         for arg in argnames:
             value = getattr(self, "_" + arg)
-            kwargs.setdefault(arg, copy.deepcopy(value))
+            if arg not in kwargs:
+                kwargs[arg] = copy.deepcopy(value)
 
         return self.__class__(**kwargs)
 
@@ -1302,6 +1306,13 @@ class MapAxis:
 
             edges_lo = table[f"{column_prefix}_LO"].quantity[0]
             edges_hi = table[f"{column_prefix}_HI"].quantity[0]
+            # for a single-valued array, it can happen that the value is stored/extracted as a scalar
+            if edges_lo.isscalar:
+                log.warning(
+                    f"'{column_prefix}' axis is stored as a scalar -- converting to 1D array."
+                )
+                edges_lo = edges_lo[np.newaxis]
+                edges_hi = edges_hi[np.newaxis]
 
             if np.allclose(edges_hi, edges_lo):
                 axis = MapAxis.from_nodes(edges_hi, interp=interp, name=name)
@@ -2555,7 +2566,8 @@ class TimeMapAxis:
 
         for arg in argnames:
             value = getattr(self, "_" + arg)
-            kwargs.setdefault(arg, copy.deepcopy(value))
+            if arg not in kwargs:
+                kwargs[arg] = copy.deepcopy(value)
 
         return self.__class__(**kwargs)
 
@@ -2630,7 +2642,7 @@ class TimeMapAxis:
             The unit to convert the edges to. Default is 'd' (day).
         interp : str
             Interpolation method used to transform between axis and pixel
-            coordinates.  Valid options are 'log', 'lin', and 'sqrt'.
+            coordinates.  Currently, only 'lin' is supported.
         name : str
             Axis name
 
@@ -2686,11 +2698,27 @@ class TimeMapAxis:
         elif format == "lightcurve":
             # TODO: is this a good format? It just supports mjd...
             name = "time"
-            scale = table.meta.get("TIMESYS", "utc")
-            time_min = Time(table["time_min"].data, format="mjd", scale=scale)
-            time_max = Time(table["time_max"].data, format="mjd", scale=scale)
-            reference_time = Time("2001-01-01T00:00:00")
-            reference_time.format = "mjd"
+            time_ref_dict = dict(
+                MJDREFF=table.meta.get("MJDREFF", 0),
+                MJDREFI=table.meta.get("MJDREFI", 0),
+                TIMESYS=table.meta.get("TIMESYS", "utc"),
+                TIMEUNIT=table.meta.get("TIMEUNIT", "d"),
+            )
+            reference_time = time_ref_from_dict(time_ref_dict, format="mjd")
+            time_min = reference_time + table["time_min"].data * u.Unit(
+                time_ref_dict["TIMEUNIT"]
+            )
+            time_max = reference_time + table["time_max"].data * u.Unit(
+                time_ref_dict["TIMEUNIT"]
+            )
+
+            if reference_time.mjd == 0:
+                # change to a more recent reference time
+                reference_time = Time(
+                    "2001-01-01T00:00:00", scale=time_ref_dict["TIMESYS"]
+                )
+                reference_time.format = "mjd"
+
             edges_min = (time_min - reference_time).to("s")
             edges_max = (time_max - reference_time).to("s")
         else:
