@@ -1023,7 +1023,7 @@ class TemplateSpatialModel(SpatialModel):
         Normalize the input map so that it integrates to unity.
     interp_kwargs : dict
         Interpolation keyword arguments passed to `gammapy.maps.Map.interp_by_coord`.
-        Default arguments are {'method': 'linear', 'fill_value': 0}.
+        Default arguments are {'method': 'linear', 'fill_value': 0, "values_scale": "log"}.
     Filename : str
         Name of the map file
     copy_data : bool
@@ -1076,6 +1076,7 @@ class TemplateSpatialModel(SpatialModel):
         interp_kwargs = {} if interp_kwargs is None else interp_kwargs
         interp_kwargs.setdefault("method", "linear")
         interp_kwargs.setdefault("fill_value", 0)
+        interp_kwargs.setdefault("values_scale", "log")
 
         self._interp_kwargs = interp_kwargs
         self.filename = filename
