@@ -12,6 +12,7 @@ from gammapy.modeling.models import (
     ConstantTemporalModel,
     EBLAbsorptionNormSpectralModel,
     ExpDecayTemporalModel,
+    FoVBackgroundModel,
     GaussianTemporalModel,
     LinearTemporalModel,
     Model,
@@ -163,6 +164,64 @@ def test_piecewise_norm_spectral_model_io():
     assert_allclose(new_model.energy, energy)
     assert_allclose(new_model.norms, [2, 5, 3, 0.5])
 
+    bkg = FoVBackgroundModel(spectral_model=model, dataset_name="")
+    bkg_dict = bkg.to_dict()
+    new_bkg = FoVBackgroundModel.from_dict(bkg_dict)
+
+    assert_allclose(new_bkg.spectral_model.parameters[0].value, 2)
+    assert_allclose(new_bkg.spectral_model.energy, energy)
+    assert_allclose(new_bkg.spectral_model.norms, [2, 5, 3, 0.5])
+
+
+@requires_data()
+def test_absorption_io_invalid_path(tmp_path):
+    dominguez = EBLAbsorptionNormSpectralModel.read_builtin("dominguez", redshift=0.5)
+    dominguez.filename = "/not/a/valid/path/ebl_dominguez11.fits.gz"
+    assert len(dominguez.parameters) == 2
+
+    model_dict = dominguez.to_dict()
+    parnames = [_["name"] for _ in model_dict["spectral"]["parameters"]]
+    assert parnames == [
+        "alpha_norm",
+        "redshift",
+    ]
+    new_model = EBLAbsorptionNormSpectralModel.from_dict(model_dict)
+
+    assert new_model.redshift.value == 0.5
+    assert new_model.alpha_norm.name == "alpha_norm"
+    assert new_model.alpha_norm.value == 1
+    assert_allclose(new_model.energy, dominguez.energy)
+    assert_allclose(new_model.param, dominguez.param)
+    assert len(new_model.parameters) == 2
+
+    dominguez.filename = "/not/a/valid/path/dominguez.fits.gz"
+    model_dict = dominguez.to_dict()
+    with pytest.raises(IOError):
+        EBLAbsorptionNormSpectralModel.from_dict(model_dict)
+
+
+@requires_data()
+def test_absorption_io_no_filename(tmp_path):
+    dominguez = EBLAbsorptionNormSpectralModel.read_builtin("dominguez", redshift=0.5)
+    dominguez.filename = None
+    assert len(dominguez.parameters) == 2
+
+    model_dict = dominguez.to_dict()
+    parnames = [_["name"] for _ in model_dict["spectral"]["parameters"]]
+    assert parnames == [
+        "alpha_norm",
+        "redshift",
+    ]
+
+    new_model = EBLAbsorptionNormSpectralModel.from_dict(model_dict)
+
+    assert new_model.redshift.value == 0.5
+    assert new_model.alpha_norm.name == "alpha_norm"
+    assert new_model.alpha_norm.value == 1
+    assert_allclose(new_model.energy, dominguez.energy)
+    assert_allclose(new_model.param, dominguez.param)
+    assert len(new_model.parameters) == 2
+
 
 @requires_data()
 def test_absorption_io(tmp_path):
